@@ -129,21 +129,21 @@ void	config(int argc, char **argv)
                         {
 				DPRS.Port = htons(atoi(pnt));
                         }
-			else if (!memcmp (buff, "APRS_SERVER_CALLSIGN", 20))
+			else if (!memcmp (buff, "APRS_STATION_CALLSIGN", 21))
 			{
 				memset (DPRS.CallSign, 0x00, 8);
 				memcpy (DPRS.CallSign, pnt, strlen(pnt));
 			}
-                        else if (!memcmp (buff, "APRS_SERVER_VALIDATION_CODE", 27))
+                        else if (!memcmp (buff, "APRS_STATION_VALIDATION_CODE", 28))
                         {
 				memset (DPRS.ValidCode, 0x00, 8);
 				memcpy (DPRS.ValidCode, pnt, strlen(pnt));
                         }
-			else if (!memcmp (buff, "APRS_BEACON_INTERVAL", 20))
+			else if (!memcmp (buff, "APRS_STATION_BEACON_INTERVAL", 28))
                         {
                                 DPRS.Interval = atoi(pnt);
                         }
-                        else if (!memcmp (buff, "APRS_COMMENT", 12))
+                        else if (!memcmp (buff, "APRS_STATION_COMMENT", 20))
                         {
                                 memset (DPRS.Comment, 0x00, 20);
                                 memcpy (DPRS.Comment, pnt, strlen(pnt));
@@ -156,7 +156,7 @@ void	config(int argc, char **argv)
                         {
 				DPRS.Long = atof(pnt) * 10000;
                         }
-			else if (!memcmp (buff, "APRS_BEACON_SEND", 16))
+			else if (!memcmp (buff, "APRS_STATION_BEACON_SEND", 24))
 			{
 				DPRS.ClientID = FALSE;
 				if (!memcmp (pnt, "ON", 2)) DPRS.ClientID = TRUE;
