@@ -32,8 +32,8 @@ struct MessageSW {
 
 struct	AprsCallTable{
 	struct	AprsCallTable	*Next;
-	char	CallLength;
-	char	CallSign[9];
+	char	CallSign[8];
+	time_t	acc_time;
 };
 
 char	DprsTemp[512];
@@ -57,3 +57,4 @@ time_t	AprsRadioTimer;
 
 struct	DPRSinfo	DPRS;
 
+mqd_t        dprs_qid;
