@@ -27,6 +27,7 @@
 		   V00.21 Added SO_REUSEADDR for each socket
 	2014.02.18 V00.22 Added DPRS
 	2014.02.20 V00.23 Fixed bug of DPRS
+		   V00.24 Changed Config file
 */
 
 #include	"dsgwd_pi.h"
@@ -55,6 +56,7 @@ in_port_t	dstPort;
 
 struct	mq_attr	rf_mattr;
 struct	mq_attr	inet_mattr;
+struct	mq_attr	dprs_mattr;
 struct  repMsg  reqConMsg;
 
 pthread_t	usb_ID;
@@ -93,6 +95,7 @@ void CloseSocket()
 
 	mq_close (rf_qid);
 	mq_close (inet_qid);
+	if (dprs_qid) mq_close(dprs_qid);
 	mq_unlink ("/dstar_rf");
 	mq_unlink ("/dstar_inet");
 
@@ -100,7 +103,7 @@ void CloseSocket()
 
         logfile = fopen (LOGFILE, "a");
 	now = time(NULL);
-        fprintf (logfile, "%24.24s dsgwd_pi %s End\n", ctime(&now), VERSION);
+        fprintf (logfile, "%24.24s dsgwd_pi %s End\n\n", ctime(&now), VERSION);
         fclose(logfile);
         exit(0);
 }
@@ -354,6 +357,8 @@ int main(int argc, const char **argv)
 	DPRS.DprsSW = FALSE;
 	DPRS.DprsStrip = FALSE;
 	DprsStripSW = FALSE;
+	dprs_qid = 0;
+	AprsCallTablePnt = NULL;
 
 	config (argc, (char **)argv);
 
@@ -443,6 +448,15 @@ int main(int argc, const char **argv)
 
 	if (DPRS.DprsSW)
 	{
+        	/* define mq attribute */
+        	dprs_mattr.mq_flags = O_NONBLOCK;
+        	dprs_mattr.mq_maxmsg = 20;
+        	dprs_mattr.mq_msgsize = 40;
+        	dprs_mattr.mq_curmsgs = 0;
+
+        	dprs_qid = mq_open ("/dprs", O_RDWR | O_CREAT,
+                	S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH, &rf_mattr);
+
         	dprsSocket = socket(PF_INET, SOCK_STREAM, 0);
 	        opt = 1;
         	if (setsockopt(dprsSocket, SOL_SOCKET, SO_REUSEADDR, &opt, sizeof(int)) != 0){
