@@ -41,6 +41,8 @@ char	CurJitterBufferPnt;
 char	VoicePacketSW;
 extern	int	voice_pnt;
 
+void    StoreAccessCall(char call[]);
+
 void	from_rig(void)
 {
 	int	length;
@@ -74,6 +76,8 @@ void	from_rig(void)
 		now = time(NULL);
 		fprintf (logfile, "%24.24s Accept from RIG %8.8s\n",ctime(&now), rf_header.MyCall);
 		fclose (logfile);
+		
+		StoreAccessCall(rf_header.MyCall);
 
 		headerRead = TRUE;
 		SendHeader = TRUE;
@@ -100,11 +104,9 @@ void	from_rig(void)
 				{
 					dv_frame.B_header.seq = Packet_Seq | 0x40;
 					send_voice_queue();
-					//Packet_Seq++;
-					//if (Packet_Seq > 20) Packet_Seq = 0;
 					logfile = fopen (LOGFILE, "a");
 					now = time(NULL);
-					fprintf (logfile, "%24.24s Frome Rig %d packets\n", ctime(&now), rf_PacketCnt);
+					fprintf (logfile, "%24.24s From Rig %d packets\n", ctime(&now), rf_PacketCnt);
 					fclose (logfile);
 					headerRead = FALSE;
 					SendHeader = FALSE;
@@ -140,6 +142,10 @@ void	from_rig(void)
 							|| (BitsCheck((char *)voice, NullVoice_ID31, 9) < MaxErrorBit)) 
 							&& SendHeader)
 						{
+							logfile = fopen (LOGFILE, "a");
+							now = time(NULL);
+							fprintf (logfile, "%24.24s Null or GPS packet\n", ctime(&now));
+							fclose (logfile);
 							SendToInet = FALSE;
 							SendHeader = FALSE;	/* header sending switch */
 						}
@@ -281,3 +287,67 @@ int	BitsCheck(char pattern1[], char pattern2[], int cnt)
 	return k;
 }
 
+void	StoreAccessCall(char call[])
+{
+	struct 	AprsCallTable	*next;
+	struct	AprsCallTable	*save;
+
+	next = AprsCallTablePnt;
+	save = next;
+	
+	while (next)
+	{
+		if (!memcmp (call, next->CallSign, 8))
+		{
+			next->acc_time = time(NULL);
+			return;
+		}
+		save = next;
+		next = next->Next;
+	}
+	next = malloc (sizeof(struct AprsCallTable));
+	memcpy (next->CallSign, call, 8);
+	next->acc_time = time(NULL);
+	next->Next = NULL;
+	if (save)
+	{
+		save->Next = next;
+	}
+	else
+	{
+		AprsCallTablePnt = next;
+	}
+}
+
+void	DeleteAccessCall(void)
+{
+	struct	AprsCallTable	*next;
+	struct	AprsCallTable	*save;
+
+	next = AprsCallTablePnt;
+	save = NULL;
+	while (next)
+	{
+		if ((time(NULL) - next->acc_time) > 600)	/* 10 min. */
+		{
+			if (save)
+			{
+				save->Next = next->Next;
+				free (next);
+				next = save->Next;	
+			}
+			else
+			{
+				AprsCallTablePnt = next->Next;
+				free (next);
+				next = AprsCallTablePnt;
+				next = save;
+			}
+		}
+		else
+		{
+			save = next;
+			next = next->Next;
+		}
+	}
+}
